from setuptools import setup

setup(name='statizy',
      version='0.1',
      description='Gaussian and Binomial distributions',
      author='Kandarp Patel',
      packages=['statizy'],
      zip_safe=False)
